@@ -1,12 +1,11 @@
+from http.client import responses
 from json.decoder import JSONDecodeError
 from typing import List
 from urllib.parse import urljoin
 
 import requests
-from requests.api import request
 from urllib3 import disable_warnings
 from urllib3.exceptions import InsecureRequestWarning
-from http.client import responses
 
 from .error import AccessDeniedError, APIError, PowerwallUnreachableError
 
@@ -162,13 +161,13 @@ class API(object):
             },
         )
 
-    def logout(self):
+    def logout(self) -> None:
         if not self.is_authenticated():
             raise APIError("Must be logged in to log out")
         # The api unsets the auth cookie and the token is invalidated
         self.get("logout")
 
-    def close(self):
+    def close(self) -> None:
         # Close the HTTP Session
         # THis method is required for testing, so python doesn't complain about unclosed resources
         self._http_session.close()
@@ -196,17 +195,13 @@ class API(object):
     def get_status(self) -> dict:
         return self.get("status")
 
-    # Endpoint not available in 1.46 and up
-    def get_device_type(self):
-        return self.get("device_type")
-
-    def get_customer_registration(self):
+    def get_customer_registration(self) -> dict:
         return self.get("customer/registration")
 
     def get_powerwalls(self):
         return self.get("powerwalls")
 
-    def get_operation(self):
+    def get_operation(self) -> dict:
         return self.get("operation")
 
     def get_networks(self) -> list:
