@@ -1,6 +1,6 @@
-from typing import Union, List
+from typing import List, Union
+
 import requests
-from packaging import version
 
 from .api import API
 from .const import (
@@ -16,17 +16,17 @@ from .const import (
     SyncType,
     User,
 )
+from .helpers import assert_attribute
 from .responses import (
+    Battery,
     LoginResponse,
     Meter,
     MetersAggregates,
     PowerwallStatus,
-    SiteMaster,
     SiteInfo,
+    SiteMaster,
     Solar,
-    Battery,
 )
-from .helpers import assert_attribute
 
 
 class Powerwall:
@@ -34,16 +34,10 @@ class Powerwall:
         self,
         endpoint: str,
         timeout: int = 10,
-        http_session: requests.Session = None,
+        http_session: Union[requests.Session, None] = None,
         verify_ssl: bool = False,
         disable_insecure_warning: bool = True,
-        pin_version: Union[str, version.Version] = None,
     ):
-        if pin_version is not None:
-            self.pin_version(pin_version)
-        else:
-            self._pin_version = None
-
         self._api = API(
             endpoint,
             timeout,
@@ -71,16 +65,16 @@ class Powerwall:
     def login(self, password: str, email: str = "", force_sm_off: bool = False) -> dict:
         return self.login_as(User.CUSTOMER, password, email, force_sm_off)
 
-    def logout(self):
+    def logout(self) -> None:
         self._api.logout()
 
     def is_authenticated(self) -> bool:
         return self._api.is_authenticated()
 
-    def run(self):
+    def run(self) -> None:
         self._api.get_sitemaster_run()
 
-    def stop(self):
+    def stop(self) -> None:
         self._api.get_sitemaster_stop()
 
     def get_charge(self) -> float:
@@ -127,7 +121,7 @@ class Powerwall:
         """Returns information about the powerwall site"""
         return SiteInfo(self._api.get_site_info())
 
-    def set_site_name(self, site_name: str):
+    def set_site_name(self, site_name: str) -> str:
         return self._api.post_site_info_site_name({"site_name": site_name})
 
     def get_status(self) -> PowerwallStatus:
@@ -135,16 +129,7 @@ class Powerwall:
 
     def get_device_type(self) -> DeviceType:
         """Returns the device type of the powerwall"""
-        if self._pin_version is None or self._pin_version >= version.Version(
-            "1.46.0"
-        ):
-            return self.get_status().device_type
-        else:
-            return DeviceType(
-                assert_attribute(
-                    self._api.get_device_type(), "device_type", "device_type"
-                )
-            )
+        return self.get_status().device_type
 
     def get_serial_numbers(self) -> List[str]:
         powerwalls = assert_attribute(
@@ -178,23 +163,12 @@ class Powerwall:
 
     def get_version(self) -> str:
         version_str = assert_attribute(self._api.get_status(), "version", "status")
-        return version_str.split(' ')[0] # newer versions include a sha trailer '21.44.1 c58c2df3'
+        return version_str.split(" ")[
+            0
+        ]  # newer versions include a sha trailer '21.44.1 c58c2df3'
 
-    def detect_and_pin_version(self) -> str:
-        self.pin_version(self.get_version())
-        return self._pin_version
-
-    def pin_version(self, vers: Union[str, version.Version]):
-        if isinstance(vers, version.Version):
-            self._pin_version = vers
-        else:
-            self._pin_version = version.Version(vers)
-
-    def get_pinned_version(self) -> version.Version:
-        return self._pin_version
-
-    def get_api(self):
+    def get_api(self) -> API:
         return self._api
 
-    def close(self):
+    def close(self) -> None:
         self._api.close()
